@@ -9,6 +9,7 @@
 # Copyright (C) 2008       Brian G. Matherly
 # Copyright (C) 2012       Doug Blank
 # Copyright (C) 2012-2013  Paul Franklin
+# Copyright (C) 2017       Serge Noiraud
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,6 +36,7 @@ Module responsible for handling the command line arguments for Gramps.
 #
 #-------------------------------------------------------------------------
 import sys
+import os
 import getopt
 import logging
 
@@ -43,12 +45,12 @@ import logging
 # gramps modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import LONGOPTS, SHORTOPTS
+from gramps.gen.const import LONGOPTS, SHORTOPTS, PLUGINS_DIR, USER_PLUGINS
+from gramps.gen.plug import BasePluginManager
 from gramps.gen.config import config
 from gramps.gen.utils.cast import get_type_converter
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
-from gramps.gen.constfunc import conv_to_unicode
 
 _HELP = _("""
 Usage: gramps.py [OPTION...]
@@ -60,16 +62,19 @@ Help options
 
 Application options
   -O, --open=FAMILY_TREE                 Open Family Tree
+  -U, --username=USERNAME                Database username
+  -P, --password=PASSWORD                Database password
   -C, --create=FAMILY_TREE               Create on open if new Family Tree
   -i, --import=FILENAME                  Import file
   -e, --export=FILENAME                  Export file
+  -r, --remove=FAMILY_TREE_PATTERN       Remove matching Family Tree(s) (use regular expressions)
   -f, --format=FORMAT                    Specify Family Tree format
   -a, --action=ACTION                    Specify action
   -p, --options=OPTIONS_STRING           Specify options
   -d, --debug=LOGGER_NAME                Enable debug logs
-  -l                                     List Family Trees
-  -L                                     List Family Trees in Detail
-  -t                                     List Family Trees, tab delimited
+  -l [FAMILY_TREE_PATTERN...]            List Family Trees
+  -L [FAMILY_TREE_PATTERN...]            List Family Trees in Detail
+  -t [FAMILY_TREE_PATTERN...]            List Family Trees, tab delimited
   -u, --force-unlock                     Force unlock of Family Tree
   -s, --show                             Show config settings
   -c, --config=[config.setting[:value]]  Set config setting(s) and start Gramps
@@ -83,10 +88,10 @@ Example of usage of Gramps command line interface
 
 1. To import four databases (whose formats can be determined from their names)
 and then check the resulting database for errors, one may type:
-gramps -i file1.ged -i file2.gpkg -i ~/db3.gramps -i file4.wft -a tool -p name=check. 
+gramps -i file1.ged -i file2.gpkg -i ~/db3.gramps -i file4.wft -a tool -p name=check.
 
 2. To explicitly specify the formats in the above example, append filenames with appropriate -f options:
-gramps -i file1.ged -f gedcom -i file2.gpkg -f gramps-pkg -i ~/db3.gramps -f gramps-xml -i file4.wft -f wft -a tool -p name=check. 
+gramps -i file1.ged -f gedcom -i file2.gpkg -f gramps-pkg -i ~/db3.gramps -f gramps-xml -i file4.wft -f wft -a tool -p name=check.
 
 3. To record the database resulting from all imports, supply -e flag
 (use -f if the filename does not allow Gramps to guess the format):
@@ -126,7 +131,7 @@ Syntax may be different for other shells and for Windows.
 #-------------------------------------------------------------------------
 # ArgParser
 #-------------------------------------------------------------------------
-class ArgParser(object):
+class ArgParser:
     """
     This class is responsible for parsing the command line arguments (if any)
     given to gramps, and determining if a GUI or a CLI session must be started.
@@ -135,16 +140,19 @@ class ArgParser(object):
     The valid options are:
 
     -O, --open=FAMILY_TREE          Open Family Tree
+    -U, --username=USERNAME         Database username
+    -P, --password=PASSWORD         Database password
     -C, --create=FAMILY_TREE        Create on open if new Family Tree
     -i, --import=FILENAME           Import file
     -e, --export=FILENAME           Export file
+    -r, --remove=PATTERN            Remove matching Family Tree(s)
     -f, --format=FORMAT             Specify Family Tree format
     -a, --action=ACTION             Specify action
     -p, --options=OPTIONS_STRING    Specify options
     -d, --debug=LOGGER_NAME         Enable debug logs
-    -l                              List Family Trees
-    -L                              List Family Trees in Detail
-    -t                              List Family Trees, tab delimited
+    -l [FAMILY_TREE...]             List Family Trees
+    -L [FAMILY_TREE...]             List Family Trees in Detail
+    -t [FAMILY_TREE...]             List Family Trees, tab delimited
     -u, --force-unlock              Force unlock of Family Tree
     -s, --show                      Show config settings
     -c, --config=SETTINGS           Set config setting(s) and start Gramps
@@ -154,32 +162,32 @@ class ArgParser(object):
     -h, --help                      Display the help
     --usage                         Display usage information
 
-    If the filename (no options) is specified, the interactive session is 
-    launched using data from filename.  In this mode (filename, no options), the 
+    If the filename (no options) is specified, the interactive session is
+    launched using data from filename.  In this mode (filename, no options), the
     rest of the arguments are ignored.  This is a mode suitable by default for
     GUI launchers, mime type handlers, and the like.
-    
+
     If no filename or -i option is given, a new interactive session (empty
     database) is launched, since no data is given anyway.
-    
+
     If -O or -i option is given, but no -e or -a options are given, an
-    interactive session is launched with the ``FILENAME`` (specified with -i). 
-    
+    interactive session is launched with the ``FILENAME`` (specified with -i).
+
     If both input (-O or -i) and processing (-e or -a) options are given,
     interactive session will not be launched.
-    
-    When using import ot export options (-i or -e), the -f option may be
+
+    When using import or export options (-i or -e), the -f option may be
     specified to indicate the family tree format.
-    
+
     Possible values for ``ACTION`` are:  'report', 'book' and 'tool'.
-    
+
     Configuration ``SETTINGS`` may be specified using the -c option.  The
     settings are of the form config.setting[:value].  If used without a value,
-    the setting is shown. 
-    
-    If the -y option is given, the user's acceptance of any CLI prompt is 
+    the setting is shown.
+
+    If the -y option is given, the user's acceptance of any CLI prompt is
     assumed. (see :meth:`.cli.user.User.prompt`)
-    
+
     If the -q option is given, extra noise on sys.stderr, such as progress
     indicators, is suppressed.
     """
@@ -192,18 +200,21 @@ class ArgParser(object):
 
         self.open_gui = None
         self.open = None
+        self.username = None
+        self.password = None
         self.exports = []
         self.actions = []
         self.imports = []
+        self.removes = []
         self.imp_db_path = None
         self.list = False
         self.list_more = False
         self.list_table = False
+        self.database_names = None
         self.help = False
         self.usage = False
         self.force_unlock = False
         self.create = None
-        self.runqml = False
         self.quiet = False
         self.auto_accept = False
 
@@ -220,39 +231,43 @@ class ArgParser(object):
         Any errors are added to self.errors
         """
         try:
-            # Convert arguments to unicode, otherwise getopt will not work
-            # if a non latin character is used as an option (by mistake).
-            # getopt will try to treat the first char in an utf-8 sequence. Example:
-            # -Ärik is '-\xc3\x84rik' and getopt will respond :
-            # option -\xc3 not recognized
-            for arg in range(len(self.args) - 1):
-                self.args[arg+1] = conv_to_unicode(self.args[arg + 1],
-                                                   sys.stdin.encoding)
             options, leftargs = getopt.getopt(self.args[1:],
-                                             SHORTOPTS, LONGOPTS)
+                                              SHORTOPTS, LONGOPTS)
         except getopt.GetoptError as msg:
             # Extract the arguments in the list.
-            # The % operator replaces the list elements with repr() of the list elemements
-            # which is OK for latin characters, but not for non latin characters in list elements
+            # The % operator replaces the list elements
+            # with repr() of the list elements
+            # which is OK for latin characters,
+            # but not for non latin characters in list elements
             cliargs = "[ "
             for arg in range(len(self.args) - 1):
                 cliargs += self.args[arg + 1] + " "
             cliargs += "]"
             # Must first do str() of the msg object.
             msg = str(msg)
-            self.errors += [(_('Error parsing the arguments'), 
-                        msg + '\n' +
-                        _("Error parsing the arguments: %s \n" 
-                        "Type gramps --help for an overview of commands, or "
-                        "read the manual pages.") % cliargs)]
+            self.errors += [(_('Error parsing the arguments'),
+                             msg + '\n' +
+                             _("Error parsing the arguments: %s \n"
+                               "Type gramps --help for an overview of "
+                               "commands, or read the manual pages."
+                              ) % cliargs)]
             return
 
+        # Some args can work on a list of databases:
+        if leftargs:
+            for opt_ix in range(len(options)):
+                option, value = options[opt_ix]
+                if option in ['-L', '-l', '-t']:
+                    self.database_names = leftargs
+                    leftargs = []
+
         if leftargs:
             # if there were an argument without option,
             # use it as a file to open and return
             self.open_gui = leftargs[0]
-            print(_("Trying to open: %s ...") % leftargs[0],
-                          file=sys.stderr)
+            print(_("Trying to open: %s ..."
+                   ) % leftargs[0],
+                  file=sys.stderr)
             #see if force open is on
             for opt_ix in range(len(options)):
                 option, value = options[opt_ix]
@@ -270,27 +285,49 @@ class ArgParser(object):
                 self.open = value
             elif option in ['-C', '--create']:
                 self.create = value
+            elif option in ['-U', '--username']:
+                self.username = value
+            elif option in ['-P', '--password']:
+                self.password = value
             elif option in ['-i', '--import']:
                 family_tree_format = None
-                if opt_ix < len(options) - 1 \
-                   and options[opt_ix + 1][0] in ( '-f', '--format'): 
+                if (opt_ix < len(options) - 1
+                        and options[opt_ix + 1][0] in ('-f', '--format')):
                     family_tree_format = options[opt_ix + 1][1]
                 self.imports.append((value, family_tree_format))
+            elif option in ['-r', '--remove']:
+                self.removes.append(value)
             elif option in ['-e', '--export']:
                 family_tree_format = None
-                if opt_ix < len(options) - 1 \
-                   and options[opt_ix + 1][0] in ( '-f', '--format'): 
+                if (opt_ix < len(options) - 1
+                        and options[opt_ix + 1][0] in ('-f', '--format')):
                     family_tree_format = options[opt_ix + 1][1]
+                abs_name = os.path.abspath(os.path.expanduser(value))
+                if not os.path.exists(abs_name):
+                    # The file doesn't exists, try to create it.
+                    try:
+                        open(abs_name, 'w').close()
+                        os.unlink(abs_name)
+                    except OSError as e:
+                        message = _("WARNING: %(strerr)s "
+                                    "(errno=%(errno)s):\n"
+                                    "WARNING: %(name)s\n") % {
+                                      'strerr' : e.strerror,
+                                      'errno'  : e.errno,
+                                      'name'   : e.filename}
+                        print(message)
+                        sys.exit(1)
                 self.exports.append((value, family_tree_format))
             elif option in ['-a', '--action']:
                 action = value
                 if action not in ('report', 'tool', 'book'):
-                    print(_("Unknown action: %s. Ignoring.") % action,
-                                  file=sys.stderr)
+                    print(_("Unknown action: %s. Ignoring."
+                           ) % action,
+                          file=sys.stderr)
                     continue
                 options_str = ""
-                if opt_ix < len(options)-1 \
-                            and options[opt_ix+1][0] in ( '-p', '--options' ): 
+                if (opt_ix < len(options)-1
+                        and options[opt_ix+1][0] in ('-p', '--options')):
                     options_str = options[opt_ix+1][1]
                 self.actions.append((action, options_str))
             elif option in ['-d', '--debug']:
@@ -304,50 +341,49 @@ class ArgParser(object):
                 self.list_more = True
             elif option in ['-t']:
                 self.list_table = True
-            elif option in ['-s','--show']:
-                print(_("Gramps config settings from %s:")
-                              % config.filename)
-                for section in config.data:
-                    for setting in config.data[section]:
-                        print("%s.%s=%s"
-                               % (section, setting,
-                                  repr(config.data[section][setting])))
+            elif option in ['-s', '--show']:
+                print(_("Gramps config settings from %s:"
+                       ) % config.filename)
+                for sect in config.data:
+                    for setting in config.data[sect]:
+                        print("%s.%s=%s" % (sect, setting,
+                                            repr(config.data[sect][setting])))
                     print()
                 sys.exit(0)
             elif option in ['-c', '--config']:
-                setting_name = value
+                cfg_name = value
                 set_value = False
-                if setting_name:
-                    if ":" in setting_name:
-                        setting_name, new_value = setting_name.split(":", 1)
+                if cfg_name:
+                    if ":" in cfg_name:
+                        cfg_name, new_value = cfg_name.split(":", 1)
                         set_value = True
-                    if config.has_default(setting_name):
-                        setting_value = config.get(setting_name)
+                    if config.has_default(cfg_name):
+                        setting_value = config.get(cfg_name)
                         print(_("Current Gramps config setting: "
-                                "%(name)s:%(value)s")
-                                    % {'name' : setting_name,
-                                       'value' : repr(setting_value)},
+                                "%(name)s:%(value)s"
+                               ) % {'name'  : cfg_name,
+                                    'value' : repr(setting_value)},
                               file=sys.stderr)
                         if set_value:
                             # does a user want the default config value?
                             if new_value in ("DEFAULT", _("DEFAULT")):
-                                new_value = config.get_default(setting_name)
+                                new_value = config.get_default(cfg_name)
                             else:
                                 converter = get_type_converter(setting_value)
                                 new_value = converter(new_value)
-                            config.set(setting_name, new_value)
+                            config.set(cfg_name, new_value)
                             # translators: indent "New" to match "Current"
                             print(_("    New Gramps config setting: "
-                                    "%(name)s:%(value)s") %
-                                        {'name' : setting_name,
-                                         'value' : repr(
-                                                 config.get(setting_name))},
+                                    "%(name)s:%(value)s"
+                                   ) % {'name'  : cfg_name,
+                                        'value' : repr(config.get(cfg_name))},
                                   file=sys.stderr)
                         else:
                             need_to_quit = True
                     else:
-                        print(_("Gramps: no such config setting: '%s'")
-                                      % setting_name, file=sys.stderr)
+                        print(_("Gramps: no such config setting: '%s'"
+                               ) % cfg_name,
+                              file=sys.stderr)
                         need_to_quit = True
                 cleandbg += [opt_ix]
             elif option in ['-h', '-?', '--help']:
@@ -356,34 +392,37 @@ class ArgParser(object):
                 self.force_unlock = True
             elif option in ['--usage']:
                 self.usage = True
-            elif option in ['--qml']:
-                self.runqml = True
             elif option in ['-y', '--yes']:
                 self.auto_accept = True
             elif option in ['-q', '--quiet']:
                 self.quiet = True
-        
+
         #clean options list
         cleandbg.reverse()
         for ind in cleandbg:
             del options[ind]
-        
-        if len(options) > 0 and self.open is None and self.imports == [] \
-                and not (self.list or self.list_more or self.list_table or
-                         self.help or self.runqml):
+
+        if (len(options) > 0
+                and self.open is None
+                and self.imports == []
+                and self.removes == []
+                and not (self.list
+                         or self.list_more
+                         or self.list_table
+                         or self.help)):
             # Extract and convert to unicode the arguments in the list.
             # The % operator replaces the list elements with repr() of
             # the list elements, which is OK for latin characters
             # but not for non-latin characters in list elements
             cliargs = "[ "
             for arg in range(len(self.args) - 1):
-                cliargs += conv_to_unicode(self.args[arg + 1],
-                                           sys.stdin.encoding) + ' '
+                cliargs += self.args[arg + 1] + ' '
             cliargs += "]"
             self.errors += [(_('Error parsing the arguments'),
                              _("Error parsing the arguments: %s \n"
                                "To use in the command-line mode, supply at "
-                               "least one input file to process.") % cliargs)]
+                               "least one input file to process."
+                              ) % cliargs)]
         if need_to_quit:
             sys.exit(0)
 
@@ -394,10 +433,13 @@ class ArgParser(object):
         """
         Determine whether we need a GUI session for the given tasks.
         """
-        if self.errors: 
+        if self.errors:
             #errors in argument parsing ==> give cli error, no gui needed
             return False
-        
+
+        if len(self.removes) > 0:
+            return False
+
         if self.list or self.list_more or self.list_table or self.help:
             return False
 
@@ -406,8 +448,8 @@ class ArgParser(object):
             return True
 
         # If we have data to work with:
-        if (self.open or self.imports):
-            if (self.exports or self.actions):
+        if self.open or self.imports:
+            if self.exports or self.actions:
                 # have both data and what to do with it => no GUI
                 return False
             elif self.create:
@@ -419,10 +461,10 @@ class ArgParser(object):
             else:
                 # data given, but no action/export => GUI
                 return True
-        
+
         # No data, can only do GUI here
         return True
-    
+
     def print_help(self):
         """
         If the user gives the --help or -h option, print the output to terminal.
