@@ -74,13 +74,11 @@ try:
         _encoding = sys.stdout.encoding
 except:
     _encoding = "UTF-8"
-
 try:
-    # On Windows there is no std handles in GUI mode
     sys.stdout = open(sys.stdout.fileno(), mode='w', encoding=_encoding,
-                      buffering=1, errors='backslashreplace')
+                  buffering=1, errors='backslashreplace')
     sys.stderr = open(sys.stderr.fileno(), mode='w', encoding=_encoding,
-                      buffering=1, errors='backslashreplace')
+                  buffering=1, errors='backslashreplace')
 except:
     pass
 
@@ -116,7 +114,7 @@ if win():
         # user directory fails here, there is no way to report the failure,
         # because stdout/stderr are not available, and neither is the logfile.
         if os.path.islink(HOME_DIR):
-            pass # ok
+            pass  # ok
         elif not os.path.isdir(HOME_DIR):
             os.makedirs(HOME_DIR)
         sys.stdout = sys.stderr = open(logfile, "w")
@@ -138,7 +136,7 @@ def exc_hook(type, value, tb):
     if type == IOError:
         # strange Windows logging error on close
         return
-    #Use this to show variables in each frame:
+    # Use this to show variables in each frame:
     #from gramps.gen.utils.debug import format_exception
     import traceback
     LOG.error("Unhandled exception\n" +
@@ -156,7 +154,7 @@ from .gen.mime import mime_type_is_defined
 #-------------------------------------------------------------------------
 
 MIN_PYTHON_VERSION = (3, 2, 0, '', 0)
-if not sys.version_info >= MIN_PYTHON_VERSION :
+if not sys.version_info >= MIN_PYTHON_VERSION:
     logging.warning(_("Your Python version does not meet the "
              "requirements. At least python %(v1)d.%(v2)d.%(v3)d is needed to"
              " start Gramps.\n\n"
@@ -166,14 +164,6 @@ if not sys.version_info >= MIN_PYTHON_VERSION :
              'v3': MIN_PYTHON_VERSION[2]})
     sys.exit(1)
 
-try:
-    import bsddb3
-except ImportError:
-    logging.warning(_("\nYou don't have the python3 bsddb3 package installed."
-        " This package is needed to start Gramps.\n\n"
-         "Gramps will terminate now."))
-    sys.exit(1)
-
 #-------------------------------------------------------------------------
 #
 # Gramps libraries
@@ -190,7 +180,7 @@ def build_user_paths():
     """ check/make user-dirs on each Gramps session"""
     for path in USER_DIRLIST:
         if os.path.islink(path):
-            pass # ok
+            pass  # ok
         elif not os.path.isdir(path):
             os.makedirs(path)
 
@@ -200,24 +190,26 @@ def show_settings():
     """
     py_str = '%d.%d.%d' % sys.version_info[:3]
     try:
+        import gi
+        gi.require_version('Gtk', '3.0')
         from gi.repository import Gtk
         try:
             gtkver_str = '%d.%d.%d' % (Gtk.get_major_version(),
                         Gtk.get_minor_version(), Gtk.get_micro_version())
-        except : # any failure to 'get' the version
+        except:  # any failure to 'get' the version
             gtkver_str = 'unknown version'
     except ImportError:
         gtkver_str = 'not found'
     # no DISPLAY is a RuntimeError in an older pygtk (e.g. 2.17 in Fedora 14)
     except RuntimeError:
         gtkver_str = 'DISPLAY not set'
-    #exept TypeError: To handle back formatting on version split
+    # exept TypeError: To handle back formatting on version split
 
     try:
         from gi.repository import GObject
         try:
             pygobjectver_str = '%d.%d.%d' % GObject.pygobject_version
-        except :# any failure to 'get' the version
+        except:  # any failure to 'get' the version
             pygobjectver_str = 'unknown version'
 
     except ImportError:
@@ -227,7 +219,7 @@ def show_settings():
         from gi.repository import Pango
         try:
             pangover_str = Pango.version_string()
-        except :# any failure to 'get' the version
+        except:  # any failure to 'get' the version
             pangover_str = 'unknown version'
 
     except ImportError:
@@ -238,7 +230,7 @@ def show_settings():
         try:
             pycairover_str = '%d.%d.%d' % cairo.version_info
             cairover_str = cairo.cairo_version_string()
-        except :# any failure to 'get' the version
+        except:  # any failure to 'get' the version
             pycairover_str = 'unknown version'
             cairover_str = 'unknown version'
 
@@ -255,7 +247,7 @@ def show_settings():
             from gi.repository import OsmGpsMap as osmgpsmap
             try:
                 osmgpsmap_str = osmgpsmap._version
-            except :# any failure to 'get' the version
+            except:  # any failure to 'get' the version
                 osmgpsmap_str = 'unknown version'
         else:
             osmgpsmap_str = 'not found'
@@ -272,20 +264,22 @@ def show_settings():
             from gi.repository import GExiv2
             try:
                 gexiv2_str = GExiv2._version
-            except: # any failure to 'get' the version
+            except:  # any failure to 'get' the version
                 gexiv2_str = 'unknown version'
         else:
             gexiv2_str = 'not found'
 
     except ImportError:
         gexiv2_str = 'not found'
+    except ValueError:
+        gexiv2_str = 'not new enough'
 
     try:
         import PyICU
         try:
             pyicu_str = PyICU.VERSION
             icu_str = PyICU.ICU_VERSION
-        except: # any failure to 'get' the version
+        except:  # any failure to 'get' the version
             pyicu_str = 'unknown version'
             icu_str = 'unknown version'
 
@@ -298,9 +292,21 @@ def show_settings():
         bsddb_str = bsddb.__version__
         bsddb_db_str = str(bsddb.db.version()).replace(', ', '.')\
                                         .replace('(', '').replace(')', '')
+        bsddb_location_str = bsddb.__file__
     except:
         bsddb_str = 'not found'
         bsddb_db_str = 'not found'
+        bsddb_location_str = 'not found'
+
+    try:
+        import sqlite3
+        sqlite3_py_version_str = sqlite3.version
+        sqlite3_version_str = sqlite3.sqlite_version
+        sqlite3_location_str = sqlite3.__file__
+    except:
+        sqlite3_version_str = 'not found'
+        sqlite3_py_version_str = 'not found'
+        sqlite3_location_str = 'not found'
 
     try:
         from .gen.const import VERSION
@@ -313,24 +319,28 @@ def show_settings():
     else:
         kernel = None
 
-    lang_str = get_env_var('LANG','not set')
-    language_str = get_env_var('LANGUAGE','not set')
-    grampsi18n_str = get_env_var('GRAMPSI18N','not set')
-    grampshome_str = get_env_var('GRAMPSHOME','not set')
-    grampsdir_str = get_env_var('GRAMPSDIR','not set')
+    lang_str = get_env_var('LANG', 'not set')
+    language_str = get_env_var('LANGUAGE', 'not set')
+    grampsi18n_str = get_env_var('GRAMPSI18N', 'not set')
+    grampshome_str = get_env_var('GRAMPSHOME', 'not set')
+    grampsdir_str = get_env_var('GRAMPSDIR', 'not set')
+    gramps_resources_str = get_env_var('GRAMPS_RESOURCES', 'not set')
 
     try:
         dotversion_str = Popen(['dot', '-V'], stderr=PIPE).communicate(input=None)[1]
         if isinstance(dotversion_str, bytes) and sys.stdin.encoding:
             dotversion_str = dotversion_str.decode(sys.stdin.encoding)
         if dotversion_str:
-            dotversion_str = dotversion_str.replace('\n','')[23:27]
+            dotversion_str = dotversion_str.replace('\n', '')[23:27]
     except:
         dotversion_str = 'Graphviz not in system PATH'
 
     try:
         if win():
-            gsversion_str = Popen(['gswin32c', '--version'], stdout=PIPE).communicate(input=None)[0]
+            try:
+                gsversion_str = Popen(['gswin32c', '--version'], stdout=PIPE).communicate(input=None)[0]
+            except:
+                gsversion_str = Popen(['gswin64c', '--version'], stdout=PIPE).communicate(input=None)[0]
         else:
             gsversion_str = Popen(['gs', '--version'], stdout=PIPE).communicate(input=None)[0]
         if isinstance(gsversion_str, bytes) and sys.stdin.encoding:
@@ -340,49 +350,60 @@ def show_settings():
     except:
         gsversion_str = 'Ghostscript not in system PATH'
 
-    os_path = get_env_var('PATH','not set')
+    os_path = get_env_var('PATH', 'not set')
     os_path = os_path.split(os.pathsep)
 
-    print ("Gramps Settings:")
-    print ("----------------")
-    print (' python    : %s' % py_str)
-    print (' gramps    : %s' % gramps_str)
-    print (' gtk++     : %s' % gtkver_str)
-    print (' pygobject : %s' % pygobjectver_str)
-    print (' pango     : %s' % pangover_str)
-    print (' bsddb     : %s' % bsddb_str)
-    print (' bsddb.db  : %s' % bsddb_db_str)
-    print (' cairo     : %s' % cairover_str)
-    print (' pycairo   : %s' % pycairover_str)
-    print (' osmgpsmap : %s' % osmgpsmap_str)
-    print (' GExiv2    : %s' % gexiv2_str)
-    print (' ICU       : %s' % icu_str)
-    print (' PyICU     : %s' % pyicu_str)
-    print (' o.s.      : %s' % sys.platform)
+    print("Gramps Settings:")
+    print("----------------")
+    print(' python    : %s' % py_str)
+    print(' gramps    : %s' % gramps_str)
+    print(' gtk++     : %s' % gtkver_str)
+    print(' pygobject : %s' % pygobjectver_str)
+    print(' pango     : %s' % pangover_str)
+    print(' cairo     : %s' % cairover_str)
+    print(' pycairo   : %s' % pycairover_str)
+    print(' osmgpsmap : %s' % osmgpsmap_str)
+    print(' GExiv2    : %s' % gexiv2_str)
+    print(' ICU       : %s' % icu_str)
+    print(' PyICU     : %s' % pyicu_str)
+    print(' o.s.      : %s' % sys.platform)
     if kernel:
-        print (' kernel    : %s' % kernel)
-    print ('')
-    print ("Environment settings:")
-    print ("---------------------")
-    print (' LANG      : %s' % lang_str)
-    print (' LANGUAGE  : %s' % language_str)
-    print (' GRAMPSI18N: %s' % grampsi18n_str)
-    print (' GRAMPSHOME: %s' % grampshome_str)
-    print (' GRAMPSDIR : %s' % grampsdir_str)
-    print (' PYTHONPATH:')
+        print(' kernel    : %s' % kernel)
+    print('')
+    print("Environment settings:")
+    print("---------------------")
+    print(' LANG      : %s' % lang_str)
+    print(' LANGUAGE  : %s' % language_str)
+    print(' GRAMPSI18N: %s' % grampsi18n_str)
+    print(' GRAMPSHOME: %s' % grampshome_str)
+    print(' GRAMPSDIR : %s' % grampsdir_str)
+    if __debug__:
+        print(' GRAMPS_RESOURCES : %s' % gramps_resources_str)
+    print(' PYTHONPATH:')
     for folder in sys.path:
-        print ("   ", folder)
-    print ('')
-    print ("Non-python dependencies:")
-    print ("------------------------")
-    print (' Graphviz  : %s' % dotversion_str)
-    print (' Ghostscr. : %s' % gsversion_str)
-    print ('')
-    print ("System PATH env variable:")
-    print ("-------------------------")
+        print("   ", folder)
+    print('')
+    print("Non-python dependencies:")
+    print("------------------------")
+    print(' Graphviz  : %s' % dotversion_str)
+    print(' Ghostscr. : %s' % gsversion_str)
+    print('')
+    print("System PATH env variable:")
+    print("-------------------------")
     for folder in os_path:
-        print ("    ", folder)
-    print ('')
+        print("    ", folder)
+    print('')
+    print("Databases:")
+    print("-------------------------")
+    print(' bsddb     :')
+    print('     version     : %s' % bsddb_str)
+    print('     db version  : %s' % bsddb_db_str)
+    print('     location    : %s' % bsddb_location_str)
+    print(' sqlite3   :')
+    print('     version     : %s' % sqlite3_version_str)
+    print('     py version  : %s' % sqlite3_py_version_str)
+    print('     location    : %s' % sqlite3_location_str)
+    print('')
 
 def run():
     error = []
@@ -404,7 +425,7 @@ def run():
                       "of Gramps are properly installed.")
                     % APP_GRAMPS)]
 
-    #we start with parsing the arguments to determine if we have a cli or a
+    # we start with parsing the arguments to determine if we have a cli or a
     # gui session
 
     if "-v" in sys.argv or "--version" in sys.argv:
@@ -437,26 +458,25 @@ def run():
 
     if argpars.need_gui():
         LOG.debug("A GUI is needed, set it up")
-        if "--qml" in sys.argv:
-            from .guiQML.grampsqml import startqml
-            startqml(error, argpars)
-        else:
-            try:
-                from .gui.grampsgui import startgtkloop
+        try:
+            from .gui.grampsgui import startgtkloop
             # no DISPLAY is a RuntimeError in an older pygtk (e.g. F14's 2.17)
-            except RuntimeError as msg:
-                error += [(_("Configuration error:"), str(msg))]
-                return error
-            startgtkloop(error, argpars)
+        except RuntimeError as msg:
+            error += [(_("Configuration error:"), str(msg))]
+            return error
+        startgtkloop(error, argpars)
     else:
-        #CLI use of Gramps
-
+        # CLI use of Gramps
         argpars.print_help()
         argpars.print_usage()
         from .cli.grampscli import startcli
         startcli(error, argpars)
 
 def main():
+    if 'GRAMPS_RESOURCES' not in os.environ:
+        resource_path, filename = os.path.split(os.path.abspath(__file__))
+        resource_path, dirname = os.path.split(resource_path)
+        os.environ['GRAMPS_RESOURCES'] = resource_path
     if win() and ('PANGOCAIRO_BACKEND' not in os.environ) and \
             config.get('preferences.alternate-fonthandler'):
         os.environ['PANGOCAIRO_BACKEND'] = "fontconfig"
