@@ -37,19 +37,15 @@ LOG = logging.getLogger('.grampletbar')
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 import time
 import os
 import configparser
-import io
 
 #-------------------------------------------------------------------------
 #
 # GNOME modules
 #
 #-------------------------------------------------------------------------
-from gi.repository import GObject
 from gi.repository import Gtk
 
 #-------------------------------------------------------------------------
@@ -57,17 +53,19 @@ from gi.repository import Gtk
 # Gramps modules
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 from gramps.gen.const import URL_MANUAL_PAGE, VERSION_DIR
 from gramps.gen.config import config
 from gramps.gen.constfunc import win
 from ..managedwindow import ManagedWindow
 from ..display import display_help, display_url
-from .grampletpane import (AVAILABLE_GRAMPLETS, 
-                           GET_AVAILABLE_GRAMPLETS, 
-                           GET_GRAMPLET_LIST, 
-                           get_gramplet_opts, 
-                           get_gramplet_options_by_name, 
-                           make_requested_gramplet, 
+from .grampletpane import (AVAILABLE_GRAMPLETS,
+                           GET_AVAILABLE_GRAMPLETS,
+                           GET_GRAMPLET_LIST,
+                           get_gramplet_opts,
+                           get_gramplet_options_by_name,
+                           make_requested_gramplet,
                            GuiGramplet)
 from .undoablebuffer import UndoableBuffer
 from ..utils import is_right_click
@@ -91,7 +89,7 @@ class GrampletBar(Gtk.Notebook):
     A class which defines the graphical representation of the GrampletBar.
     """
     def __init__(self, dbstate, uistate, pageview, configfile, defaults):
-        GObject.GObject.__init__(self)
+        Gtk.Notebook.__init__(self)
 
         self.dbstate = dbstate
         self.uistate = uistate
@@ -109,7 +107,7 @@ class GrampletBar(Gtk.Notebook):
         book_button = Gtk.Button()
         # Arrow is too small unless in a box
         box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
-        arrow = Gtk.Arrow(arrow_type=Gtk.ArrowType.DOWN, 
+        arrow = Gtk.Arrow(arrow_type=Gtk.ArrowType.DOWN,
                                     shadow_type=Gtk.ShadowType.NONE)
         arrow.show()
         box.add(arrow)
@@ -130,7 +128,7 @@ class GrampletBar(Gtk.Notebook):
         for opts in opts_list:
             if opts["name"] in AVAILABLE_GRAMPLETS():
                 all_opts = get_gramplet_opts(opts["name"], opts)
-                gramplet = make_requested_gramplet(TabGramplet, self, all_opts, 
+                gramplet = make_requested_gramplet(TabGramplet, self, all_opts,
                                                    self.dbstate, self.uistate)
                 if gramplet:
                     self.__add_tab(gramplet)
@@ -220,50 +218,49 @@ class GrampletBar(Gtk.Notebook):
         """
         filename = self.configfile
         try:
-            fp = io.open(filename, "w", encoding='utf-8')
+            with open(filename, "w", encoding='utf-8') as fp:
+                fp.write(";; Gramplet bar configuration file" + NL)
+                fp.write((";; Automatically created at %s" %
+                                         time.strftime("%Y/%m/%d %H:%M:%S")) + NL + NL)
+                fp.write("[Bar Options]" + NL)
+                fp.write(("visible=%s" + NL) % self.get_property('visible'))
+                fp.write(("page=%d" + NL) % self.get_current_page())
+                fp.write(NL)
+
+                if self.empty:
+                    gramplet_list = []
+                else:
+                    gramplet_list = [self.get_nth_page(page_num)
+                                     for page_num in range(self.get_n_pages())]
+
+                for page_num, gramplet in enumerate(gramplet_list):
+                    opts = get_gramplet_options_by_name(gramplet.gname)
+                    if opts is not None:
+                        base_opts = opts.copy()
+                        for key in base_opts:
+                            if key in gramplet.__dict__:
+                                base_opts[key] = gramplet.__dict__[key]
+                        fp.write(("[%s]" + NL) % gramplet.gname)
+                        for key in base_opts:
+                            if key in ["content", "title", "tname", "row", "column",
+                                       "page", "version", "gramps"]: # don't save
+                                continue
+                            elif key == "data":
+                                if not isinstance(base_opts["data"], (list, tuple)):
+                                    fp.write(("data[0]=%s" + NL) % base_opts["data"])
+                                else:
+                                    cnt = 0
+                                    for item in base_opts["data"]:
+                                        fp.write(("data[%d]=%s" + NL) % (cnt, item))
+                                        cnt += 1
+                            else:
+                                fp.write(("%s=%s" + NL)% (key, base_opts[key]))
+                        fp.write(("page=%d" + NL) % page_num)
+                        fp.write(NL)
+
         except IOError:
             LOG.warning("Failed writing '%s'; gramplets not saved" % filename)
             return
-        fp.write(";; Gramplet bar configuration file" + NL)
-        fp.write((";; Automatically created at %s" %
-                                 time.strftime("%Y/%m/%d %H:%M:%S")) + NL + NL)
-        fp.write("[Bar Options]" + NL)
-        fp.write(("visible=%s" + NL) % self.get_property('visible'))
-        fp.write(("page=%d" + NL) % self.get_current_page())
-        fp.write(NL) 
-
-        if self.empty:
-            gramplet_list = []
-        else:
-            gramplet_list = [self.get_nth_page(page_num)
-                             for page_num in range(self.get_n_pages())]
-
-        for page_num, gramplet in enumerate(gramplet_list):
-            opts = get_gramplet_options_by_name(gramplet.gname)
-            if opts is not None:
-                base_opts = opts.copy()
-                for key in base_opts:
-                    if key in gramplet.__dict__:
-                        base_opts[key] = gramplet.__dict__[key]
-                fp.write(("[%s]" + NL) % gramplet.gname)
-                for key in base_opts:
-                    if key in ["content", "title", "tname", "row", "column", 
-                               "page", "version", "gramps"]: # don't save
-                        continue
-                    elif key == "data":
-                        if not isinstance(base_opts["data"], (list, tuple)):
-                            fp.write(("data[0]=%s" + NL) % base_opts["data"])
-                        else:
-                            cnt = 0
-                            for item in base_opts["data"]:
-                                fp.write(("data[%d]=%s" + NL) % (cnt, item))
-                                cnt += 1
-                    else:
-                        fp.write(("%s=%s" + NL)% (key, base_opts[key]))
-                fp.write(("page=%d" + NL) % page_num)
-                fp.write(NL)
-
-        fp.close()
 
     def set_active(self):
         """
@@ -373,7 +370,7 @@ class GrampletBar(Gtk.Notebook):
         """
         Add a tab to the notebook for the given gramplet.
         """
-        width = min(int(self.uistate.screen_width() * 0.25), 400)
+        width = -1  # Allow tab width to adjust (smaller) to sidebar
         height = min(int(self.uistate.screen_height() * 0.20), 400)
         gramplet.set_size_request(width, height)
 
@@ -461,7 +458,7 @@ class GrampletBar(Gtk.Notebook):
         if self.get_n_pages() == 0:
             self.empty = True
             self.__create_empty_tab()
-        
+
     def __create_window(self, grampletbar, gramplet, x_pos, y_pos):
         """
         Called when the user has switched to a new GrampletBar page.
@@ -544,11 +541,13 @@ class GrampletBar(Gtk.Notebook):
         """
         Called when restore defaults is clicked from the context menu.
         """
-        QuestionDialog(_("Restore to defaults?"),
+        QuestionDialog(
+            _("Restore to defaults?"),
             _("The gramplet bar will be restored to contain its default "
               "gramplets.  This action cannot be undone."),
             _("OK"),
-            self.restore)
+            self.restore,
+            parent=self.uistate.window)
 
     def get_config_funcs(self):
         """
@@ -587,7 +586,7 @@ class TabGramplet(Gtk.ScrolledWindow, GuiGramplet):
         """
         Internal constructor for GUI portion of a gramplet.
         """
-        GObject.GObject.__init__(self)
+        Gtk.ScrolledWindow.__init__(self)
         GuiGramplet.__init__(self, pane, dbstate, uistate, title, **kwargs)
 
         self.scrolledwindow = self
@@ -671,7 +670,7 @@ class DetachedWindow(ManagedWindow):
                 else:
                     display_help(self.gramplet.help_url)
             else:
-                display_help(WIKI_HELP_PAGE, 
+                display_help(WIKI_HELP_PAGE,
                                    self.gramplet.tname.replace(" ", "_"))
 
     def get_notebook(self):
@@ -714,7 +713,7 @@ class TabLabel(Gtk.Box):
     """
     def __init__(self, gramplet, callback):
         Gtk.Box.__init__(self)
-        
+
         self.text = gramplet.title
         self.set_spacing(4)
 
@@ -766,5 +765,5 @@ def cb_menu_position(*args):
     ret_val, x_pos, y_pos = button.get_window().get_origin()
     x_pos += button.get_allocation().x
     y_pos += button.get_allocation().y + button.get_allocation().height
-    
+
     return (x_pos, y_pos, False)
