@@ -1,7 +1,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
-# Copyright (C) 2007-2008  Brian G. Matherly
+# Copyright (C) 2007-2012  Brian G. Matherly
 # Copyright (C) 2010       Jakim Friant
 # Copyright (C) 2014       Paul Franklin
 # Copyright (C) 2010-2015  Craig J. Anderson
@@ -28,28 +28,30 @@
 # Python modules
 #
 #------------------------------------------------------------------------
-from __future__ import division
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
 
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
+from gramps.gen.errors import ReportError
 from gramps.gen.plug.menu import (TextOption, NumberOption, BooleanOption,
                                   EnumeratedListOption, StringOption,
                                   PersonOption)
 from gramps.gen.plug.report import Report, MenuReportOptions, stdoptions
-from gramps.gen.plug.report import utils as ReportUtils
+from gramps.gen.plug.report import utils
 from gramps.gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
                                     FONT_SANS_SERIF, PARA_ALIGN_CENTER)
 from gramps.plugins.lib.libtreebase import *
 from gramps.plugins.lib.librecurse import AscendPerson
+from gramps.gen.proxy import CacheProxyDb
+from gramps.gen.display.name import displayer as _nd
 
-PT2CM = ReportUtils.pt2cm
-#cm2pt = ReportUtils.cm2pt
+PT2CM = utils.pt2cm
+#cm2pt = utils.cm2pt
 
 #------------------------------------------------------------------------
 #
@@ -103,7 +105,7 @@ class TitleN(TitleNoDisplay):
     """No Title class for the report """
 
     def __init__(self, doc, locale):
-        TitleNoDisplay.__init__(self, doc, "AC2-Title")
+        TitleNoDisplay.__init__(self, doc, "AC2-Title-box")
         self._ = locale.translation.sgettext
 
     def calc_title(self, center):
@@ -116,7 +118,7 @@ class TitleA(TitleBox):
     """Title class for the report """
     def __init__(self, doc, locale, name_displayer):
         self._nd = name_displayer
-        TitleBox.__init__(self, doc, "AC2-Title")
+        TitleBox.__init__(self, doc, "AC2-Title-box")
         self._ = locale.translation.sgettext
 
     def calc_title(self, center):
@@ -136,34 +138,34 @@ class TitleA(TitleBox):
 # make_ancestor_tree  (main recursive functions)
 #
 #------------------------------------------------------------------------
-class CalcItems(object):
+class CalcItems:
     """ A helper class to calculate the default box text
     and text for each person / marriage
     """
     def __init__(self, dbase):
-        __gui = GUIConnect()
-        self._gui = __gui
+        _gui = GUIConnect()
+        self._gui = _gui
 
         #calculate the printed lines for each box
         #str = ""
         #if self.get_val('miss_val'):
         #    str = "_____"
-        display_repl = __gui.get_val("replace_list")
-        self.__calc_l = CalcLines(dbase, display_repl, __gui._locale, __gui._nd)
+        display_repl = _gui.get_val("replace_list")
+        self.__calc_l = CalcLines(dbase, display_repl, _gui.locale, _gui.n_d)
 
         self.__blank_father = None
         self.__blank_mother = None
 
         self.__blank_father = \
-            self.__calc_l.calc_lines( None, None, __gui.get_val("father_disp"))
+            self.__calc_l.calc_lines(None, None, _gui.get_val("father_disp"))
         self.__blank_mother = \
-            self.__calc_l.calc_lines( None, None, __gui.get_val("mother_disp"))
+            self.__calc_l.calc_lines(None, None, _gui.get_val("mother_disp"))
 
-        self.center_use = __gui.get_val("center_uses")
-        self.disp_father = __gui.get_val("father_disp")
-        self.disp_mother = __gui.get_val("mother_disp")
+        self.center_use = _gui.get_val("center_uses")
+        self.disp_father = _gui.get_val("father_disp")
+        self.disp_mother = _gui.get_val("mother_disp")
 
-        self.disp_marr = [__gui.get_val("marr_disp")]
+        self.disp_marr = [_gui.get_val("marr_disp")]
         self.__blank_marriage = \
             self.__calc_l.calc_lines(None, None, self.disp_marr)
 
@@ -186,14 +188,14 @@ class CalcItems(object):
             return working_lines
         else:
             return self.__calc_l.calc_lines(indi_handle, fams_handle,
-                                    working_lines)
+                                            working_lines)
 
     def calc_marriage(self, indi_handle, fams_handle):
         if indi_handle == fams_handle == None:
             return self.__blank_marriage
         else:
             return self.__calc_l.calc_lines(indi_handle, fams_handle,
-                                self.disp_marr)
+                                            self.disp_marr)
 
 class MakeAncestorTree(AscendPerson):
     """
@@ -229,8 +231,8 @@ class MakeAncestorTree(AscendPerson):
         if index[LVL_GEN] > self.max_generation:
             self.max_generation = index[LVL_GEN]
 
-        myself.text = self.calc_items.calc_person(
-                            index, indi_handle, fams_handle)
+        myself.text = self.calc_items.calc_person(index,
+                                                  indi_handle, fams_handle)
         # myself.text[0] = myself.text[0] + ' ' + repr(index) # for debugging
 
         if indi_handle is not None: # None is legal for an empty box
@@ -285,12 +287,13 @@ class MakeAncestorTree(AscendPerson):
         first off of a forumula, then remove blank areas around the edges,
         then compress the tree if desired
         '''
-        min_y = self.y_index(self.canvas.boxes[0].level[LVL_GEN], 
-                self.canvas.boxes[0].level[LVL_INDX])
+        min_y = self.y_index(self.canvas.boxes[0].level[LVL_GEN],
+                             self.canvas.boxes[0].level[LVL_INDX])
         for box in self.canvas.boxes:
             if "fam" in box.boxstr:
                 box.level = box.level + \
-                    (self.y_index(box.level[LVL_GEN]-1, int(box.level[LVL_INDX]/2)),)
+                    (self.y_index(box.level[LVL_GEN]-1,
+                                  int(box.level[LVL_INDX]/2)),)
             else:
                 box.level = box.level + \
                     (self.y_index(box.level[LVL_GEN], box.level[LVL_INDX]),)
@@ -315,7 +318,7 @@ class MakeAncestorTree(AscendPerson):
             y_index = box.level[LVL_Y]
             if y_index > current_y:
                 current_y = y_index
-                y_level += 1 
+                y_level += 1
             box.level = box.level[:LVL_Y] + (y_level,)
 
     def do_sibs(self):
@@ -335,24 +338,28 @@ class MakeAncestorTree(AscendPerson):
 
         move = level - (len(mykids)//2) + ((len(mykids)+1)%2)
 
-        if move < 0:  # more kids than parents.  ran off the page.  Move them all down
+        if move < 0:
+            # more kids than parents.  ran off the page.  Move them all down
             for box in self.canvas.boxes:
                 box.level = (box.level[0], box.level[1], box.level[2]-move)
             move = 0
-        
+
 
         line.start = []
-        r = -1  # if len(mykids)%2 == 1 else 0
+        rrr = -1  # if len(mykids)%2 == 1 else 0
         for kid in mykids:
-            r += 1
-            me = self.add_person((1, 1, move+r), kid, self.center_family)
-            line.add_from(me)
-            #me.level = (0, 1, level - (len(mykids)//2)+r )
+            rrr += 1
+            mee = self.add_person((1, 1, move+rrr), kid, self.center_family)
+            line.add_from(mee)
+            #mee.level = (0, 1, level - (len(mykids)//2)+rrr)
 
 
     def start(self, person_id):
         """ go ahead and make it happen """
         center = self.database.get_person_from_gramps_id(person_id)
+        if center is None:
+            raise ReportError(
+                _("Person %s is not in the Database") % person_id)
         center_h = center.get_handle()
 
         #Step 1.  Get the people
@@ -373,7 +380,7 @@ class MakeAncestorTree(AscendPerson):
 #------------------------------------------------------------------------
 # Class lr_Transform
 #------------------------------------------------------------------------
-class LRTransform(object):
+class LRTransform:
     """
     setup all of the boxes on the canvas in for a left/right report
     """
@@ -387,7 +394,7 @@ class LRTransform(object):
         #1. cm_x
         box.x_cm = self.rept_opts.littleoffset
         box.x_cm += (box.level[LVL_GEN] *
-                (self.rept_opts.col_width + self.rept_opts.max_box_width))
+                     (self.rept_opts.col_width + self.rept_opts.max_box_width))
         #2. cm_y
         box.y_cm = self.rept_opts.max_box_height + self.rept_opts.box_pgap
         box.y_cm *= box.level[LVL_Y]
@@ -408,7 +415,7 @@ class LRTransform(object):
 # class make_report
 #
 #------------------------------------------------------------------------
-class MakeReport(object):
+class MakeReport:
 
     def __init__(self, dbase, doc, canvas, font_normal):
 
@@ -449,7 +456,7 @@ class MakeReport(object):
         return self.max_generations
 
     def start(self):
-        __gui = GUIConnect()
+        ## __gui = GUIConnect()
         # 1.
         #set the sizes for each box and get the max_generations.
         self.father_ht = 0.0
@@ -478,7 +485,7 @@ class MakeReport(object):
         transform.place()
 
 
-class GUIConnect(object):
+class GUIConnect:
     """ This is a BORG object.  There is ONLY one.
     This give some common routines that EVERYONE can use like
       get the value from a GUI variable
@@ -491,8 +498,8 @@ class GUIConnect(object):
     def set__opts(self, options, locale, name_displayer):
         """ Set only once as we are BORG.  """
         self.__opts = options
-        self._locale = locale
-        self._nd = name_displayer
+        self.locale = locale
+        self.n_d = name_displayer
 
     def get_val(self, val):
         """ Get a GUI value. """
@@ -507,9 +514,9 @@ class GUIConnect(object):
         GUI options """
         title_type = self.get_val('report_title')
         if title_type:
-            return TitleA(doc, self._locale, self._nd)
+            return TitleA(doc, self.locale, self.n_d)
         else:
-            return TitleN(doc, self._locale)
+            return TitleN(doc, self.locale)
 
     def inc_marr(self):
         return self.get_val("inc_marr")
@@ -532,6 +539,7 @@ class GUIConnect(object):
 #
 #------------------------------------------------------------------------
 class AncestorTree(Report):
+    """ AncestorTree Report """
 
     def __init__(self, database, options, user):
         """
@@ -539,7 +547,7 @@ class AncestorTree(Report):
 
         The arguments are:
 
-        database        - the GRAMPS database instance
+        database        - the Gramps database instance
         options         - instance of the Options class for this report
         user            - a gen.user.User() instance
         """
@@ -548,10 +556,11 @@ class AncestorTree(Report):
         self.options = options
         self._user = user
 
+        self.set_locale(options.menu.get_option_by_name('trans').get_value())
+        stdoptions.run_date_format_option(self, options.menu)
         stdoptions.run_private_data_option(self, options.menu)
-
-        lang = options.menu.get_option_by_name('trans').get_value()
-        self._locale = self.set_locale(lang)
+        stdoptions.run_living_people_option(self, options.menu, self._locale)
+        self.database = CacheProxyDb(self.database)
         stdoptions.run_name_format_option(self, options.menu)
         self._nd = self._name_display
 
@@ -566,8 +575,9 @@ class AncestorTree(Report):
         scale_report - Whether to scale the report to fit the width or all.
         indblank     - Whether to include blank pages.
         compress     - Whether to compress chart.
-
-        incl_private    - Whether to include private data
+        incl_private - Whether to include private data
+        living_people - How to handle living people
+        years_past_death - Consider as living this many years after death
 
         We will
         1. a canvas in its full one-page size
@@ -587,7 +597,7 @@ class AncestorTree(Report):
 
         #The canvas that we will put our report on and print off of
         self.canvas = Canvas(self.doc,
-                        ReportOptions(self.doc, font_normal, 'AC2-line'))
+                             ReportOptions(self.doc, font_normal, 'AC2-line'))
 
         self.canvas.report_opts.box_shadow *= \
                         self.connect.get_val('shadowscale')
@@ -595,10 +605,10 @@ class AncestorTree(Report):
         self.canvas.report_opts.box_mgap *= self.connect.get_val('box_Yscale')
 
         with self._user.progress(_('Ancestor Tree'),
-                _('Making the Tree...'), 4) as step:
+                                 _('Making the Tree...'), 4) as step:
 
             #make the tree onto the canvas
-            inlc_marr = self.connect.get_val("inc_marr")
+            ## inlc_marr = self.connect.get_val("inc_marr")
             self.max_generations = self.connect.get_val('maxgen')
             tree = MakeAncestorTree(database, self.canvas)
             tree.start(self.connect.get_val('pid'))
@@ -609,8 +619,7 @@ class AncestorTree(Report):
             #Title
             title = self.connect.title_class(self.doc)
             center = self.database.get_person_from_gramps_id(
-                        self.connect.get_val('pid')
-                        )
+                self.connect.get_val('pid'))
             title.calc_title(center)
             self.canvas.add_title(title)
 
@@ -638,7 +647,8 @@ class AncestorTree(Report):
             scale_report = self.connect.get_val("scale_tree")
 
             scale = self.canvas.scale_report(one_page,
-                                             scale_report != 0, scale_report == 2)
+                                             scale_report != 0,
+                                             scale_report == 2)
 
             step()
 
@@ -661,7 +671,7 @@ class AncestorTree(Report):
         colsperpage = self.doc.get_usable_width()
         colsperpage += self.canvas.report_opts.col_width
         colsperpage = int(colsperpage / (self.canvas.report_opts.max_box_width +
-                                       self.canvas.report_opts.col_width))
+                                         self.canvas.report_opts.col_width))
         colsperpage = colsperpage or 1
 
         #####################
@@ -680,8 +690,8 @@ class AncestorTree(Report):
         #lets finally make some pages!!!
         #####################
         pages = self.canvas.page_count(incblank)
-        with self._user.progress( _('Ancestor Tree'),
-                _('Printing the Tree...'), pages) as step:
+        with self._user.progress(_('Ancestor Tree'),
+                                 _('Printing the Tree...'), pages) as step:
 
             for page in self.canvas.page_iter_gen(incblank):
 
@@ -763,22 +773,32 @@ class AncestorTreeOptions(MenuReportOptions):
     """
 
     def __init__(self, name, dbase):
+        self.__db = dbase
+        self.__pid = None
         self.box_Y_sf = None
         self.box_shadow_sf = None
         MenuReportOptions.__init__(self, name, dbase)
 
+    def get_subject(self):
+        """ Return a string that describes the subject of the report. """
+        gid = self.__pid.get_value()
+        person = self.__db.get_person_from_gramps_id(gid)
+        return _nd.display(person)
+
     def add_menu_options(self, menu):
 
         ##################
         category_name = _("Tree Options")
 
-        pid = PersonOption(_("Center Person"))
-        pid.set_help(_("The center person for the tree"))
-        menu.add_option(category_name, "pid", pid)
+        self.__pid = PersonOption(_("Center Person"))
+        self.__pid.set_help(_("The center person for the tree"))
+        menu.add_option(category_name, "pid", self.__pid)
 
-        siblings = BooleanOption(_('Include siblings of the center person'), False)
-        siblings.set_help(_("Whether to only display the center person or all "
-            "of his/her siblings too"))
+        siblings = BooleanOption(
+            _('Include siblings of the center person'), False)
+        siblings.set_help(
+            _("Whether to only display the center person or all "
+              "of his/her siblings too"))
         menu.add_option(category_name, "inc_siblings", siblings)
 
         self.max_gen = NumberOption(_("Generations"), 10, 1, 50)
@@ -796,16 +816,17 @@ class AncestorTreeOptions(MenuReportOptions):
         self.__fillout_vals()
 
         compress = BooleanOption(_('Compress tree'), True)
-        compress.set_help(_("Whether to remove any extra blank spaces set "
-            "aside for people that are unknown"))
+        compress.set_help(
+            _("Whether to remove any extra blank spaces set "
+              "aside for people that are unknown"))
         menu.add_option(category_name, "compress_tree", compress)
 
         #better to 'Show siblings of\nthe center person
         #Spouse_disp = EnumeratedListOption(_("Show spouses of\nthe center "
         #                                     "person"), 0)
-        #Spouse_disp.add_item( 0, _("No.  Do not show Spouses"))
-        #Spouse_disp.add_item( 1, _("Yes, and use the Main Display Format"))
-        #Spouse_disp.add_item( 2, _("Yes, and use the Secondary "
+        #Spouse_disp.add_item(0, _("No.  Do not show Spouses"))
+        #Spouse_disp.add_item(1, _("Yes, and use the Main Display Format"))
+        #Spouse_disp.add_item(2, _("Yes, and use the Secondary "
         #                           "Display Format"))
         #Spouse_disp.set_help(_("Show spouses of the center person?"))
         #menu.add_option(category_name, "Spouse_disp", Spouse_disp)
@@ -827,60 +848,6 @@ class AncestorTreeOptions(MenuReportOptions):
         prnnum.set_help(_("Whether to print page numbers on each page."))
         menu.add_option(category_name, "inc_pagenum", prnnum)
 
-        stdoptions.add_private_data_option(menu, category_name)
-
-        stdoptions.add_name_format_option(menu, category_name)
-
-        stdoptions.add_localization_option(menu, category_name)
-
-        ##################
-        category_name = _("Display")
-
-        disp = TextOption(_("Father\nDisplay Format"),
-                           ["$n",
-                            "%s $b" %_BORN,
-                            "-{%s $d}" %_DIED])
-        disp.set_help(_("Display format for the fathers box."))
-        menu.add_option(category_name, "father_disp", disp)
-
-        #Will add when libsubstkeyword supports it.
-        #missing = EnumeratedListOption(_("Replace missing\nplaces\\dates \
-        #                                 with"), 0)
-        #missing.add_item( 0, _("Does not display anything"))
-        #missing.add_item( 1, _("Displays '_____'"))
-        #missing.set_help(_("What will print when information is not known"))
-        #menu.add_option(category_name, "miss_val", missing)
-
-        #category_name = _("Secondary")
-
-        dispMom = TextOption(_("Mother\nDisplay Format"),
-                               ["$n",
-                                "%s $b" %_BORN,
-                                "%s $m" %_MARR,
-                                "-{%s $d}" %_DIED]
-                            )
-        dispMom.set_help(_("Display format for the mothers box."))
-        menu.add_option(category_name, "mother_disp", dispMom)
-
-        centerDisp = EnumeratedListOption(_("Center person uses\n"
-                                        "which format"), 0)
-        centerDisp.add_item(0, _("Use Fathers Display format"))
-        centerDisp.add_item(1, _("Use Mothers display format"))
-        centerDisp.set_help(_("Which Display format to use the center person"))
-        menu.add_option(category_name, "center_uses", centerDisp)
-
-        incmarr = BooleanOption(_('Include Marriage box'), False)
-        incmarr.set_help(
-            _("Whether to include a separate marital box in the report"))
-        menu.add_option(category_name, "inc_marr", incmarr)
-
-        marrdisp = StringOption(_("Marriage\nDisplay Format"), "%s $m" % _MARR)
-        marrdisp.set_help(_("Display format for the marital box."))
-        menu.add_option(category_name, "marr_disp", marrdisp)
-
-        ##################
-        category_name = _("Size")
-
         self.scale = EnumeratedListOption(_("Scale tree to fit"), 0)
         self.scale.add_item(0, _("Do not scale tree"))
         self.scale.add_item(1, _("Scale tree to fit page width only"))
@@ -892,62 +859,106 @@ class AncestorTreeOptions(MenuReportOptions):
         self.scale.connect('value-changed', self.__check_blank)
 
         if "BKI" not in self.name.split(","):
-            self.__onepage = BooleanOption(_("Resize Page to Fit Tree size\n"
-                "\n"
-                "Note: Overrides options in the 'Paper Option' tab"
-                ),
+            self.__onepage = BooleanOption(
+                _("Resize Page to Fit Tree size\n"
+                  "\n"
+                  "Note: Overrides options in the 'Paper Option' tab"
+                 ),
                 False)
             self.__onepage.set_help(
                 _("Whether to resize the page to fit the size \n"
-                "of the tree.  Note:  the page will have a \n"
-                "non standard size.\n"
-                "\n"
-                "With this option selected, the following will happen:\n"
-                "\n"
-                "With the 'Do not scale tree' option the page\n"
-                "  is resized to the height/width of the tree\n"
-                "\n"
-                "With 'Scale tree to fit page width only' the height of\n"
-                "  the page is resized to the height of the tree\n"
-                "\n"
-                "With 'Scale tree to fit the size of the page' the page\n"
-                "  is resized to remove any gap in either height or width"
-                ))
+                  "of the tree.  Note:  the page will have a \n"
+                  "non standard size.\n"
+                  "\n"
+                  "With this option selected, the following will happen:\n"
+                  "\n"
+                  "With the 'Do not scale tree' option the page\n"
+                  "  is resized to the height/width of the tree\n"
+                  "\n"
+                  "With 'Scale tree to fit page width only' the height of\n"
+                  "  the page is resized to the height of the tree\n"
+                  "\n"
+                  "With 'Scale tree to fit the size of the page' the page\n"
+                  "  is resized to remove any gap in either height or width"
+                 ))
             menu.add_option(category_name, "resize_page", self.__onepage)
             self.__onepage.connect('value-changed', self.__check_blank)
         else:
             self.__onepage = None
 
-        self.box_Y_sf = NumberOption(_("inter-box scale factor"),
-                                     1.00, 0.10, 2.00, 0.01)
-        self.box_Y_sf.set_help(_("Make the inter-box spacing bigger or smaller"))
-        menu.add_option(category_name, "box_Yscale", self.box_Y_sf)
-
-        self.box_shadow_sf = NumberOption(_("box shadow scale factor"),
-                                          1.00, 0.00, 2.00, 0.01) # down to 0
-        self.box_shadow_sf.set_help(_("Make the box shadow bigger or smaller"))
-        menu.add_option(category_name, "shadowscale", self.box_shadow_sf)
-
-
-        ##################
-        category_name = _("Replace")
-
-        repldisp = TextOption(
-            _("Replace Display Format:\n'Replace this'/' with this'"),
-            [])
-        repldisp.set_help(_("i.e.\nUnited States of America/U.S.A"))
-        menu.add_option(category_name, "replace_list", repldisp)
-
-
-        ##################
-        category_name = _("Include")
-
         self.__blank = BooleanOption(_('Include Blank Pages'), True)
         self.__blank.set_help(_("Whether to include pages that are blank."))
         menu.add_option(category_name, "inc_blank", self.__blank)
 
         self.__check_blank()
 
+        ##################
+        category_name = _("Report Options (2)")
+
+        stdoptions.add_name_format_option(menu, category_name)
+
+        stdoptions.add_living_people_option(menu, category_name)
+
+        stdoptions.add_private_data_option(menu, category_name)
+
+        locale_opt = stdoptions.add_localization_option(menu, category_name)
+
+        stdoptions.add_date_format_option(menu, category_name, locale_opt)
+
+        ##################
+        category_name = _("Display")
+
+        disp = TextOption(_("Father\nDisplay Format"),
+                          ["$n",
+                           "%s $b" %_BORN,
+                           "-{%s $d}" %_DIED])
+        disp.set_help(_("Display format for the fathers box."))
+        menu.add_option(category_name, "father_disp", disp)
+
+        #Will add when libsubstkeyword supports it.
+        #missing = EnumeratedListOption(_("Replace missing\nplaces\\dates \
+        #                                 with"), 0)
+        #missing.add_item(0, _("Does not display anything"))
+        #missing.add_item(1, _("Displays '_____'"))
+        #missing.set_help(_("What will print when information is not known"))
+        #menu.add_option(category_name, "miss_val", missing)
+
+        disp_mom = TextOption(_("Mother\nDisplay Format"),
+                              ["$n",
+                               "%s $b" %_BORN,
+                               "%s $m" %_MARR,
+                               "-{%s $d}" %_DIED])
+        disp_mom.set_help(_("Display format for the mothers box."))
+        menu.add_option(category_name, "mother_disp", disp_mom)
+
+        center_disp = EnumeratedListOption(_("Center person uses\n"
+                                             "which format"), 0)
+        center_disp.add_item(0, _("Use Fathers Display format"))
+        center_disp.add_item(1, _("Use Mothers display format"))
+        center_disp.set_help(_("The display format for the center person"))
+        menu.add_option(category_name, "center_uses", center_disp)
+
+        self.incmarr = BooleanOption(_('Include Marriage box'), False)
+        self.incmarr.set_help(
+            _("Whether to include a separate marital box in the report"))
+        menu.add_option(category_name, "inc_marr", self.incmarr)
+        self.incmarr.connect('value-changed', self._incmarr_changed)
+
+        self.marrdisp = StringOption(_("Marriage\nDisplay Format"),
+                                       "%s $m" % _MARR)
+        self.marrdisp.set_help(_("Display format for the marital box."))
+        menu.add_option(category_name, "marr_disp", self.marrdisp)
+        self._incmarr_changed()
+
+        ##################
+        category_name = _("Advanced")
+
+        repldisp = TextOption(
+            _("Replace Display Format:\n'Replace this'/' with this'"),
+            [])
+        repldisp.set_help(_("i.e.\nUnited States of America/U.S.A"))
+        menu.add_option(category_name, "replace_list", repldisp)
+
         # TODO this code is never used and so I conclude it is for future use
         # self.__include_images = BooleanOption(
         #                       _('Include thumbnail images of people'), False)
@@ -955,12 +966,10 @@ class AncestorTreeOptions(MenuReportOptions):
         #                       _("Whether to include thumbnails of people."))
         # menu.add_option(category_name, "includeImages", self.__include_images)
 
-        #category_name = _("Notes")
-
         self.usenote = BooleanOption(_('Include a note'), False)
-        self.usenote.set_help(_("Whether to include a note on "
-                                "the report."))
+        self.usenote.set_help(_("Whether to include a note on the report."))
         menu.add_option(category_name, "inc_note", self.usenote)
+        self.usenote.connect('value-changed', self._usenote_changed)
 
         self.notedisp = TextOption(_("Note"), [])
         self.notedisp.set_help(_("Add a note\n\n"
@@ -973,6 +982,32 @@ class AncestorTreeOptions(MenuReportOptions):
             self.notelocal.add_item(num, text)
         self.notelocal.set_help(_("Where to place the note."))
         menu.add_option(category_name, "note_place", self.notelocal)
+        self._usenote_changed()
+
+        self.box_Y_sf = NumberOption(_("inter-box scale factor"),
+                                     1.00, 0.10, 2.00, 0.01)
+        self.box_Y_sf.set_help(
+            _("Make the inter-box spacing bigger or smaller"))
+        menu.add_option(category_name, "box_Yscale", self.box_Y_sf)
+
+        self.box_shadow_sf = NumberOption(_("box shadow scale factor"),
+                                          1.00, 0.00, 2.00, 0.01) # down to 0
+        self.box_shadow_sf.set_help(_("Make the box shadow bigger or smaller"))
+        menu.add_option(category_name, "shadowscale", self.box_shadow_sf)
+
+    def _incmarr_changed(self):
+        """
+        If Marriage box is not enabled, disable Marriage Display Format box
+        """
+        value = self.incmarr.get_value()
+        self.marrdisp.set_available(value)
+
+    def _usenote_changed(self):
+        """
+        If Note box is not enabled, disable Note Location box
+        """
+        value = self.usenote.get_value()
+        self.notelocal.set_available(value)
 
     def __check_blank(self):
         if self.__onepage:
@@ -992,10 +1027,10 @@ class AncestorTreeOptions(MenuReportOptions):
             item_list.append([1, _("One Generation of empty boxes "
                                    "for unknown ancestors")])
 
-        item_list.extend([itr, str(itr) +
-                _(" Generations of empty boxes for unknown ancestors")]
-                    for itr in range(2, max_gen)
-                )
+        item_list.extend(
+            [itr, str(itr) +
+             _(" Generations of empty boxes for unknown ancestors")]
+            for itr in range(2, max_gen))
 
         self.fillout.set_items(item_list)
         if old_val+2 > len(item_list):
@@ -1010,8 +1045,8 @@ class AncestorTreeOptions(MenuReportOptions):
         font.set_type_face(FONT_SANS_SERIF)
         para_style = ParagraphStyle()
         para_style.set_font(font)
-        para_style.set_description(_('The basic style used for the '
-                                     'text display.'))
+        para_style.set_description(
+            _('The basic style used for the text display.'))
         default_style.add_paragraph_style("AC2-Normal", para_style)
         box_shadow = PT2CM(font.get_size()) * .6
 
@@ -1020,8 +1055,8 @@ class AncestorTreeOptions(MenuReportOptions):
         font.set_type_face(FONT_SANS_SERIF)
         para_style = ParagraphStyle()
         para_style.set_font(font)
-        para_style.set_description(_('The basic style used for the '
-                                     'note display.'))
+        para_style.set_description(
+            _('The basic style used for the note display.'))
         default_style.add_paragraph_style("AC2-Note", para_style)
 
         font = FontStyle()
@@ -1030,8 +1065,7 @@ class AncestorTreeOptions(MenuReportOptions):
         para_style = ParagraphStyle()
         para_style.set_font(font)
         para_style.set_alignment(PARA_ALIGN_CENTER)
-        para_style.set_description(_('The basic style used for the '
-                                     'title display.'))
+        para_style.set_description(_('The style used for the title.'))
         default_style.add_paragraph_style("AC2-Title", para_style)
 
         ## Draw styles
@@ -1052,12 +1086,14 @@ class AncestorTreeOptions(MenuReportOptions):
         graph_style.set_fill_color((255, 255, 255))
         default_style.add_draw_style("AC2-note-box", graph_style)
 
+        # TODO this seems meaningless, as only the text is displayed
         graph_style = GraphicsStyle()
         graph_style.set_paragraph_style("AC2-Title")
         graph_style.set_color((0, 0, 0))
         graph_style.set_fill_color((255, 255, 255))
         graph_style.set_line_width(0)
-        default_style.add_draw_style("AC2-Title", graph_style)
+        graph_style.set_description(_("Cannot edit this reference"))
+        default_style.add_draw_style("AC2-Title-box", graph_style)
 
         graph_style = GraphicsStyle()
         default_style.add_draw_style("AC2-line", graph_style)
