@@ -3,7 +3,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2011  Serge Noiraud
+# Copyright (C) 2011-2016  Serge Noiraud
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,14 +28,10 @@ Geography for one person
 # Python modules
 #
 #-------------------------------------------------------------------------
-import os
-import sys
 import operator
 from gi.repository import Gdk
 KEY_TAB = Gdk.KEY_Tab
-import socket
 from gi.repository import Gtk
-from gi.repository import GObject
 from gi.repository import GLib
 
 #-------------------------------------------------------------------------
@@ -59,11 +55,6 @@ from gramps.gen.datehandler import displayer
 from gramps.gen.display.name import displayer as _nd
 from gramps.gen.display.place import displayer as _pd
 from gramps.gen.utils.place import conv_lat_lon
-from gramps.gui.views.pageview import PageView
-from gramps.gui.editors import EditPlace
-from gramps.gui.selectors.selectplace import SelectPlace
-from gramps.gui.filters.sidebar import PersonSidebarFilter
-from gramps.gui.views.navigationview import NavigationView
 from gramps.gui.views.bookmarks import PersonBookmarks
 from gramps.plugins.lib.maps import constants
 from gramps.plugins.lib.maps.geography import GeoGraphyView
@@ -100,8 +91,8 @@ _UI_DEF = '''\
 </menubar>
 <toolbar name="ToolBar">
 <placeholder name="CommonNavigation">
-  <toolitem action="Back"/>  
-  <toolitem action="Forward"/>  
+  <toolitem action="Back"/>
+  <toolitem action="Forward"/>
   <toolitem action="HomePerson"/>
 </placeholder>
 <placeholder name="CommonEdit">
@@ -111,6 +102,11 @@ _UI_DEF = '''\
 </ui>
 '''
 
+# pylint: disable=no-member
+# pylint: disable=maybe-no-member
+# pylint: disable=unused-variable
+# pylint: disable=unused-argument
+
 #-------------------------------------------------------------------------
 #
 # GeoView
@@ -148,7 +144,7 @@ class GeoPerson(GeoGraphyView):
 
     def __init__(self, pdata, dbstate, uistate, nav_group=0):
         GeoGraphyView.__init__(self, _("Person places map"),
-                                      pdata, dbstate, uistate, 
+                                      pdata, dbstate, uistate,
                                       PersonBookmarks,
                                       nav_group)
         self.dbstate = dbstate
@@ -163,6 +159,9 @@ class GeoPerson(GeoGraphyView):
         self.sort = []
         self.additional_uis.append(self.additional_ui())
         self.no_show_places_in_status_bar = False
+        self.already_started = False
+        self.large_move = False
+        self.cal = None
 
     def get_title(self):
         """
@@ -173,11 +172,11 @@ class GeoPerson(GeoGraphyView):
     def get_stock(self):
         """
         Returns the name of the stock icon to use for the display.
-        This assumes that this icon has already been registered 
+        This assumes that this icon has already been registered
         as a stock icon.
         """
         return 'geo-show-person'
-    
+
     def get_viewtype_stock(self):
         """Type of view in category
         """
@@ -202,11 +201,7 @@ class GeoPerson(GeoGraphyView):
         Rebuild the tree with the given person handle as the root.
         """
         active = self.get_active()
-        if handle:
-            self._createmap(handle)
-        elif active:
-            p1 = self.dbstate.db.get_person_from_handle(active)
-            self._createmap(p1)
+        self._createmap(None)
         self.uistate.modify_statusbar(self.dbstate)
 
     def build_tree(self):
@@ -215,8 +210,11 @@ class GeoPerson(GeoGraphyView):
         all handling of visibility is now in rebuild_trees, see that for more
         information.
         """
+        if not self.dbstate.is_open():
+            return
         active = self.get_active()
-        self._createmap(active)
+        self._createmap(None)
+        self.uistate.modify_statusbar(self.dbstate)
 
     def animate(self, menu, marks, index, stepyear):
         """
@@ -227,8 +225,8 @@ class GeoPerson(GeoGraphyView):
             self.already_started = False
             return False
         i = int(index)
-        ni = i + 1
-        if ni == len(marks) :
+        next_i = i + 1
+        if next_i == len(marks):
             self.already_started = False
             return False
         startlat = float(marks[i][3])
@@ -238,58 +236,59 @@ class GeoPerson(GeoGraphyView):
             self.remove_all_gps()
             self.large_move = False
             self.osm.gps_add(startlat, startlon, heading)
-        endlat = float(marks[ni][3])
-        endlon = float(marks[ni][4])
+        endlat = float(marks[next_i][3])
+        endlon = float(marks[next_i][4])
         max_lon_lat = float(self._config.get("geography.maximum_lon_lat")) / 10
         if stepyear < 9000:
-            if (( abs(float(endlat) - float(startlat)) > max_lon_lat ) or
-                ( abs(float(endlon) - float(startlon)) > max_lon_lat )):
+            if ((abs(float(endlat) - float(startlat)) > max_lon_lat) or
+                (abs(float(endlon) - float(startlon)) > max_lon_lat)):
                 self.large_move = True
                 stepyear = 9000
             else:
                 self.large_move = False
         # year format = YYYYMMDD ( for sort )
         startyear = str(marks[i][6])[0:4]
-        endyear = str(marks[ni][6])[0:4]
+        endyear = str(marks[next_i][6])[0:4]
         endmov = str(marks[len(marks)-1][6])[0:4]
         years = int(endyear) - int(startyear)
         if years < 1:
             years = 1
         if stepyear > 8999:
-            latstep = ( endlat - startlat ) / self._config.get("geography.steps")
-            lonstep = ( endlon - startlon ) / self._config.get("geography.steps")
-            startlat += ( latstep * (stepyear - 8999) )
-            startlon += ( lonstep * (stepyear - 8999) )
+            latstep = (endlat - startlat) / self._config.get("geography.steps")
+            lonstep = (endlon - startlon) / self._config.get("geography.steps")
+            startlat += (latstep * (stepyear - 8999))
+            startlon += (lonstep * (stepyear - 8999))
         else:
-            latstep = ( endlat - startlat ) / years
-            lonstep = ( endlon - startlon ) / years
+            latstep = (endlat - startlat) / years
+            lonstep = (endlon - startlon) / years
             stepyear = 1 if stepyear < 1 else stepyear
-            startlat += ( latstep * stepyear )
-            startlon += ( lonstep * stepyear )
+            startlat += (latstep * stepyear)
+            startlon += (lonstep * stepyear)
         self.osm.gps_add(startlat, startlon, heading)
         stepyear += 1
-        difflat = round(( startlat - endlat ) if startlat > endlat else \
-                                           ( endlat - startlat ), 8)
-        difflon = round(( startlon - endlon ) if startlon > endlon else \
-                                           ( endlon - startlon ), 8)
-        if ( difflat == 0.0 and difflon == 0.0 ):
+        difflat = round((startlat - endlat) if startlat > endlat else \
+                                           (endlat - startlat), 8)
+        difflon = round((startlon - endlon) if startlon > endlon else \
+                                           (endlon - startlon), 8)
+        if difflat == 0.0 and difflon == 0.0:
             i += 1
             self.large_move = False
             stepyear = 1
-        # if geography.speed = 100 => 100ms => 1s per 10 years. 
+        # if geography.speed = 100 => 100ms => 1s per 10 years.
         # For a 100 years person, it takes 10 secondes.
         # if large_move, one step is the difflat or difflon / geography.steps
         # in this case, stepyear is >= 9000
-        # large move means longitude or latitude differences greater than geography.maximum_lon_lat
-        # degrees.
+        # large move means longitude or latitude differences greater than
+        # geography.maximum_lon_lat degrees.
         GLib.timeout_add(int(self._config.get("geography.speed")), self.animate,
                          menu, marks, i, stepyear)
         return False
 
-    def _createmap(self,obj):
+    def _createmap(self, active):
         """
-        Create all markers for each people's event in the database which has 
+        Create all markers for each people's event in the database which has
         a lat/lon.
+        @param: active is mandatory but unused in this view. Fix : 10088
         """
         dbstate = self.dbstate
         self.cal = config.get('preferences.calendar-format-report')
@@ -306,20 +305,24 @@ class GeoPerson(GeoGraphyView):
         self.message_layer.clear_messages()
         self.kml_layer.clear()
         person_handle = self.uistate.get_active('Person')
-        person = dbstate.db.get_person_from_handle(person_handle)
+        person = None
+        if person_handle:
+            person = dbstate.db.get_person_from_handle(person_handle)
         if person is not None:
             # For each event, if we have a place, set a marker.
             self.load_kml_files(person)
-            self.message_layer.add_message(_("Person places for %s") % _nd.display(person))
+            self.message_layer.add_message(
+                                _("Person places for %s") % _nd.display(person))
             for event_ref in person.get_event_ref_list():
                 if not event_ref:
                     continue
                 event = dbstate.db.get_event_from_handle(event_ref.ref)
                 self.load_kml_files(event)
                 role = event_ref.get_role()
-                eyear = str("%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
-                          str("%02d" % event.get_date_object().to_calendar(self.cal).get_month()) + \
-                          str("%02d" % event.get_date_object().to_calendar(self.cal).get_day())
+                eyear = str(
+         "%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
+     str("%02d" % event.get_date_object().to_calendar(self.cal).get_month()) + \
+     str("%02d" % event.get_date_object().to_calendar(self.cal).get_day())
                 place_handle = event.get_place_handle()
                 if place_handle:
                     place = dbstate.db.get_place_from_handle(place_handle)
@@ -337,7 +340,7 @@ class GeoPerson(GeoGraphyView):
                         # place.get_longitude and place.get_latitude return
                         # one string. We have coordinates when the two values
                         # contains non null string.
-                        if ( longitude and latitude ):
+                        if longitude and latitude:
                             self._append_to_places_list(descr, evt,
                                                         _nd.display(person),
                                                         latitude, longitude,
@@ -357,36 +360,44 @@ class GeoPerson(GeoGraphyView):
                 if family is not None:
                     fhandle = family_list[0] # first is primary
                     fam = dbstate.db.get_family_from_handle(fhandle)
+                    father = mother = None
                     handle = fam.get_father_handle()
-                    father = dbstate.db.get_person_from_handle(handle)
+                    if handle:
+                        father = dbstate.db.get_person_from_handle(handle)
                     descr1 = " - "
                     if father:
                         descr1 = "%s - " % _nd.display(father)
                     handle = fam.get_mother_handle()
-                    mother = dbstate.db.get_person_from_handle(handle)
+                    if handle:
+                        mother = dbstate.db.get_person_from_handle(handle)
                     if mother:
-                        descr1 = "%s%s" % ( descr1, _nd.display(mother))
+                        descr1 = "%s%s" % (descr1, _nd.display(mother))
                     for event_ref in family.get_event_ref_list():
                         if event_ref:
-                            event = dbstate.db.get_event_from_handle(event_ref.ref)
+                            event = dbstate.db.get_event_from_handle(
+                                                                  event_ref.ref)
                             self.load_kml_files(event)
                             role = event_ref.get_role()
                             if event.get_place_handle():
                                 place_handle = event.get_place_handle()
                                 if place_handle:
-                                    place = dbstate.db.get_place_from_handle(place_handle)
+                                    place = dbstate.db.get_place_from_handle(
+                                                                   place_handle)
                                     if place:
                                         longitude = place.get_longitude()
                                         latitude = place.get_latitude()
-                                        latitude, longitude = conv_lat_lon(latitude,
-                                                                           longitude, "D.D8")
+                                        (latitude,
+                                         longitude) = conv_lat_lon(latitude,
+                                                                   longitude,
+                                                                   "D.D8")
                                         descr = _pd.display(dbstate.db, place)
                                         evt = EventType(event.get_type())
-                                        eyear = str("%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
-                                                  str("%02d" % event.get_date_object().to_calendar(self.cal).get_month()) + \
-                                                  str("%02d" % event.get_date_object().to_calendar(self.cal).get_day())
+                                        eyear = str(
+         "%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
+     str("%02d" % event.get_date_object().to_calendar(self.cal).get_month()) + \
+     str("%02d" % event.get_date_object().to_calendar(self.cal).get_day())
                                         self.load_kml_files(place)
-                                        if ( longitude and latitude ):
+                                        if longitude and latitude:
                                             self._append_to_places_list(descr,
                                                  evt, _nd.display(person),
                                                  latitude, longitude,
@@ -398,7 +409,7 @@ class GeoPerson(GeoGraphyView):
                                                  role
                                                  )
                                         else:
-                                            self._append_to_places_without_coord( place.gramps_id, descr)
+                                            self._append_to_places_without_coord(place.gramps_id, descr)
 
             self.sort = sorted(self.place_list,
                                key=operator.itemgetter(6)
@@ -464,16 +475,18 @@ class GeoPerson(GeoGraphyView):
             date = displayer.display(evt.get_date_object())
             if date == "":
                 date = _("Unknown")
-            if ( mark[11] == EventRoleType.PRIMARY ):
-                message = "(%s) %s : %s" % ( date, mark[2], mark[1] )
-            elif ( mark[11] == EventRoleType.FAMILY ):
-                (father_name, mother_name) = self._get_father_and_mother_name(evt)
-                message = "(%s) %s : %s - %s" % ( date, mark[7], father_name, mother_name )
+            if mark[11] == EventRoleType.PRIMARY:
+                message = "(%s) %s : %s" % (date, mark[2], mark[1])
+            elif mark[11] == EventRoleType.FAMILY:
+                (father_name,
+                 mother_name) = self._get_father_and_mother_name(evt)
+                message = "(%s) %s : %s - %s" % (date, mark[7],
+                                                 father_name, mother_name)
             else:
                 descr = evt.get_description()
                 if descr == "":
                     descr = _('No description')
-                message = "(%s) %s => %s" % ( date, mark[11], descr)
+                message = "(%s) %s => %s" % (date, mark[11], descr)
             prevmark = mark
         add_item = Gtk.MenuItem(label=message)
         add_item.show()
@@ -496,10 +509,10 @@ class GeoPerson(GeoGraphyView):
                    None, event.button, event.time)
         return 1
 
-    def add_specific_menu(self, menu, event, lat, lon): 
-        """ 
+    def add_specific_menu(self, menu, event, lat, lon):
+        """
         Add specific entry to the navigation menu.
-        """ 
+        """
         add_item = Gtk.MenuItem()
         add_item.show()
         menu.append(add_item)
@@ -529,14 +542,15 @@ class GeoPerson(GeoGraphyView):
                 _('Animation speed in milliseconds (big value means slower)'),
                 1, line_wrap=False)
         configdialog.add_slider(grid,
-                "", 
+                "",
                 2, 'geography.speed',
                 (100, 1000))
-        configdialog.add_text(grid,
-                _('How many steps between two markers when we are on large move ?'),
-                3, line_wrap=False)
+        configdialog.add_text(
+            grid,
+            _('How many steps between two markers when we are on large move ?'),
+            3, line_wrap=False)
         configdialog.add_slider(grid,
-                "", 
+                "",
                 4, 'geography.steps',
                 (10, 100))
         configdialog.add_text(grid,
@@ -544,7 +558,7 @@ class GeoPerson(GeoGraphyView):
                   'The value is in tenth of degree.'),
                 5, line_wrap=False)
         configdialog.add_slider(grid,
-                "", 
+                "",
                 6, 'geography.maximum_lon_lat',
                 (5, 50))
         return _('The animation parameters'), grid
